# pyenerginetpowerrightnow

A small python library to access electrical energy statistics for Denmark - as provided by https://energinet.dk/energisystemet-lige-nu/

# How to use

See test.py for an example of how to use this endpoint.


# Disclaimer

This project has no affiliation with Energinet. The purpose of this project is to increase the value of publicly available information, by making it available through more channels.
If any of this is a problem for you, please get in touch.

(This disclaimer is hopefully not really necessary.)
